@@ -1,4 +1,4 @@
-## Copyright (C) 2018  Brodie Gaslam
+## Copyright (C) 2020  Brodie Gaslam
 ##
 ## This file is part of "fansi - ANSI Control Sequence Aware String Functions"
 ##
@@ -29,11 +29,17 @@
     fansi.tabs.as.spaces=FALSE,
     fansi.tab.stops=8L,
     fansi.warn=TRUE,
+    fansi.ctrl="all",
     fansi.term.cap=c(
       if(isTRUE(Sys.getenv('COLORTERM') %in% c('truecolor', '24bit')))
       'truecolor',
       'bright', '256'
     ),
+    # This is not a particularly good default setting as it may exceed or fail
+    # to cover the interline distance when two lines have background colors.  To
+    # ensure lines are exactly touching use inline-block, although that has it's
+    # own issues.  Otherwise specify your own values.
+
     fansi.css="PRE.fansi SPAN {padding-top: .25em; padding-bottom: .25em};"
   )
   # Scheme defaults are fairly complex...
