@@ -25,11 +25,12 @@ unitizer_sect("substr", {
     grn.bg, lorem.cn.pieces[3], rgb.und, lorem.cn.pieces[4], end
   )
   lor.cn.c.2.5 <- rep(lorem.cn.col.2, 5)
-  starts <- seq(1, by=6, len=5)
+  starts <- seq(1, by=6, length.out=5)
   ends <- starts + 5
   substr2_ctl(lor.cn.c.2.5, starts, ends, term.cap=term.cap)
+  substr2_sgr(lor.cn.c.2.5, starts, ends, term.cap=term.cap)
 
-  starts <- seq(1, by=12, len=5)
+  starts <- seq(1, by=12, length.out=5)
   ends <- starts + 11
   substr2_ctl(lor.cn.c.2.5, starts, ends, type='width', term.cap=term.cap)
 
@@ -50,7 +51,7 @@ unitizer_sect("substr", {
   )
   lor.cn.c.3.5 <- rep(lorem.cn.col.3, 5)
 
-  starts <- seq(1, by=12, len=5)
+  starts <- seq(1, by=12, length.out=5)
   ends <- starts + 10
   ends[2] <- 24
 
@@ -237,8 +238,9 @@ unitizer_sect("Corner cases", {
   substr_ctl(b.t.c, 4, 4)
 
   substr2_ctl(b.t.c, 0, 0, type='width')
-  substr2_ctl(b.t.c, 0, 2, type='width')
-  substr2_ctl(b.t.c, 1, 4, type='width')
+  ## Commented out due to bug introduced by r79799 in r-devel
+  # substr2_ctl(b.t.c, 0, 2, type='width')
+  # substr2_ctl(b.t.c, 1, 4, type='width')
   substr2_ctl(b.t.c, 0, 5, type='width')
   substr2_ctl(b.t.c, 5, 5, type='width')
 })
@@ -282,8 +284,13 @@ unitizer_sect("nchar", {
 
   esc.2 <- "\n\r\033P\033[31m\a"
   nchar_ctl(c(esc.1, esc.2, 'hello'), warn=FALSE)
-})
 
+  # _sgr
+
+  esc.4 <- c(sprintf("\033[31m%s\thello", w1), NA, hello.illegal)
+  nchar_sgr(esc.4, type='width', keepNA=FALSE, warn=FALSE, allowNA=TRUE)
+  nzchar_sgr(esc.4, keepNA=FALSE, warn=FALSE)
+})
 unitizer_sect("unhandled", {
   # a bad utf8 string and other bad stuff
 
@@ -400,3 +407,29 @@ unitizer_sect("wrap with wide UTF8 and ESC", {
   Encoding(string) <- "UTF-8"
   strwrap2_ctl(string, 24, wrap.always=TRUE, pad.end=" ")
 })
+unitizer_sect("issue 54 ctd", {
+  # other issu54 tests are in tohtml.R, but had to move this one here due to the
+  # ellipsis utf-8 character.
+
+  string3 <- c(
+    "\033[38;5;246m# … with 5 more variables: total_time \033[3m\033[38;5;246m<bch:tm>\033[38;5;246m\033[23m, result \033[3m\033[38;5;246m<list>\033[38;5;246m\033[23m, memory \033[3m\033[38;5;246m<list>\033[38;5;246m\033[23m,",
+    "#   time \033[3m\033[38;5;246m<list>\033[38;5;246m\033[23m, gc \033[3m\033[38;5;246m<list>\033[38;5;246m\033[23m\033[39m"
+  )
+  Encoding(string3) <- "UTF-8"
+  fansi::sgr_to_html(string3)
+
+  # head <- "<html><head><meta charset='utf-8'/></head><pre>"
+  # f <- paste0(tempfile(), ".html")
+  # writeLines(c(head, fansi::sgr_to_html(string3), "</pre></html>"), f)
+  # browseURL(f)
+  # unlink(f)
+
+  # trigger warnings/errors
+
+  string4 <- c(
+    "wow \033[31m then", "hello\033[\x80;wow", "yo \033[m there",
+    "boom \033[41m"
+  )
+  Encoding(string4) <- "UTF-8"
+  sgr_to_html(string4)
+})
